@@ -1,6 +1,6 @@
 #' @title Bayesian Discount Prior: Binomial counts
 #' @description \code{bdpbinomial} is used for estimating posterior samples from a
-#'   Binomial outcome where an informative prior is used. The prior weight
+#'   binomial outcome where an informative prior is used. The prior weight
 #'   is determined using a discount function. This code is modeled after
 #'   the methodologies developed in Haddad et al. (2017).
 #' @param y_t scalar. Number of events for the current treatment group.
@@ -28,8 +28,7 @@
 #'   where the first value is used to estimate the weight of the historical
 #'   treatment group and the second value is used to estimate the weight of the
 #'   historical control group.
-#' @param number_mcmc scalar. Number of Markov Chain Monte Carlo (MCMC)
-#'   simulations. Default is 10000.
+#' @param number_mcmc scalar. Number of Monte Carlo simulations. Default is 10000.
 #' @param a0 scalar. Prior value for the beta rate. Default is 1.
 #' @param b0 scalar. Prior value for the beta rate. Default is 1.
 #' @param two_side logical. Indicator of two-sided test for the discount
@@ -57,16 +56,19 @@
 #'  distribution of the current data augmented by the historical data.
 #'
 #'  To carry our a two-arm (RCT) analysis, data for the current treatment and
-#'  current control (\code{y_c} and \code{N_c}) must be input,
-#'  as well as at least one of the historical treatment and historical control
-#'  (\code{y0_c} and \code{N0_c}). The results
+#'  at least one of current or historical control data must be input. The results
 #'  are then based on the posterior distribution of the difference between
 #'  current treatment and control, augmented by available historical data.
 #'
-#' @return \code{bdpbinomial} returns an object of class "bdpbinomial".
-#' The functions \code{summary} and \code{print} are used to obtain and
-#' print a summary of the results, including user inputs. The \code{plot}
-#' function displays visual outputs as well.
+#'   For more details, see the \code{bdpbinomial} vignette: \cr
+#'   \code{vignette("bdpbinomial-vignette", package="bayesDP")}
+#'
+#' @return \code{bdpbinomial} returns an object of class "bdpbinomial". The
+#'   functions \code{\link[=summary,bdpbinomial-method]{summary}} and
+#'   \code{\link[=print,bdpbinomial-method]{print}} are used to obtain and
+#'   print a summary of the results, including user inputs. The
+#'   \code{\link[=plot,bdpbinomial-method]{plot}} function displays visual
+#'   outputs as well.
 #'
 #' An object of class \code{bdpbinomial} is a list containing at least
 #' the following components:
@@ -81,43 +83,23 @@
 #'        numeric. The posterior probability of the stochastic comparison
 #'        between the current and historical data.}
 #'      \item{\code{posterior}}{
-#'        vector. The posterior of the treatment group, incorporating the
-#'        weighted historical data.}
+#'        vector. A vector of length \code{number_mcmc} containing
+#'        posterior Monte Carlo samples of the event rate of the treatment
+#'        group. If historical treatment data is present, the posterior
+#'        incorporates the weighted historical data.}
 #'      \item{\code{posterior_flat}}{
-#'        vector. The distribution of the current treatment group, i.e., no
-#'        incorporation of the historical data.}
+#'        vector. A vector of length \code{number_mcmc} containing
+#'        Monte Carlo samples of the event rate of the current treatment group
+#'        under a flat/non-informative prior, i.e., no incorporation of the
+#'        historical data.}
 #'      \item{\code{prior}}{
-#'        vector. The distribution of the historical treatment group.}
+#'        vector. If historical treatment data is present, a vector of length
+#'        \code{number_mcmc} containing Monte Carlo samples of the event rate
+#'        of the historical treatment group under a flat/non-informative prior.}
 #'   }
 #'  \item{\code{posterior_control}}{
-#'    list. Similar entries as \code{posterior_treament}. Only present if
+#'    list. Similar entries as \code{posterior_treament}. Only present if a
 #'    control group is specified.}
-#'  \item{\code{f1}}{
-#'    list. Entries contain values related to the posterior effect:}
-#'    \itemize{
-#'      \item{\code{density_post_treatment}}{
-#'        object of class \code{density}. Used internally to plot the density of
-#'        the treatment group posterior.}
-#'      \item{\code{density_flat_treatment}}{
-#'        object of class \code{density}. Used internally to plot the density of
-#'        the treatment group "flat" distribution.}
-#'      \item{\code{density_prior_treatment}}{
-#'        object of class \code{density}. Used internally to plot the density of
-#'        the treatment group prior.}
-#'      \item{\code{density_post_control}}{
-#'        object of class \code{density}. Used internally to plot the density of
-#'        the control group (if present) posterior.}
-#'      \item{\code{density_flat_control}}{
-#'        object of class \code{density}. Used internally to plot the density of
-#'        the control group (if present) "flat" distribution.}
-#'      \item{\code{density_prior_control}}{
-#'        object of class \code{density}. Used internally to plot the density of
-#'        the control group (if present) prior.}
-#'      \item{\code{comparison_posterior}}{
-#'        vector. If control group is present, vector contains posterior
-#'        distribution of the effect estimate of treatment vs. control.
-#'        control groups.}
-#'   }
 #'  \item{\code{args1}}{
 #'    list. Entries contain user inputs. In addition, the following elements
 #'    are ouput:}
@@ -131,6 +113,17 @@
 #'   }
 #' }
 #'
+#' @seealso \code{\link[=summary,bdpbinomial-method]{summary}},
+#'   \code{\link[=print,bdpbinomial-method]{print}},
+#'   and \code{\link[=plot,bdpbinomial-method]{plot}} for details of each of the
+#'   supported methods.
+#'
+#' @references
+#' Haddad, T., Himes, A., Thompson, L., Irony, T., Nair, R. MDIC Computer
+#'   Modeling and Simulation working group.(2017) Incorporation of stochastic
+#'   engineering models as prior information in Bayesian medical device trials.
+#'   \emph{Journal of Biopharmaceutical Statistics}, 1-15.
+#'
 #' @examples
 #' # One-arm trial (OPC) example
 #' fit <- bdpbinomial(y_t           = 10,
@@ -139,7 +132,9 @@
 #'                    N0_t          = 250)
 #' summary(fit)
 #' print(fit)
-#' #plot(fit)
+#' \dontrun{
+#' plot(fit)
+#' }
 #'
 #' # Two-arm (RCT) example
 #' fit2 <- bdpbinomial(y_t = 10,
@@ -152,17 +147,18 @@
 #'                     N0_c = 250)
 #' summary(fit2)
 #' print(fit2)
-#' #plot(fit2)
+#' \dontrun{
+#' plot(fit2)
+#' }
 #'
 #' @rdname bdpbinomial
 #' @import methods
-#' @importFrom stats density is.empty.model median model.offset model.response pweibull quantile rbeta rgamma rnorm var vcov
+#' @importFrom stats sd density is.empty.model median model.offset model.response pweibull quantile rbeta rgamma rnorm var vcov
 #' @aliases bdpbinomial,ANY-method
 #' @export bdpbinomial
 bdpbinomial <- setClass("bdpbinomial",
                         slots = c(posterior_test = "list",
                                   posterior_control = "list",
-                                  f1 = "list",
                                   args1 = "list"))
 
 setGeneric("bdpbinomial",
@@ -326,16 +322,10 @@ setMethod("bdpbinomial",
       weibull_scale = weibull_scale[2],
       weibull_shape = weibull_shape[2],
       two_side      = two_side)
+  } else{
+    posterior_control <- NULL
   }
 
-  if(arm2){
-    f1 <- final_binomial(posterior_treatment = posterior_treatment,
-                         posterior_control   = posterior_control)
-  }
-  else{
-    f1 <- final_binomial(posterior_treatment = posterior_treatment,
-                         posterior_control   = NULL)
-  }
 
   args1 <- list(y_t           = y_t,
                 N_t           = N_t,
@@ -356,16 +346,9 @@ setMethod("bdpbinomial",
                 arm2          = arm2,
                 intent        = paste(intent,collapse=", "))
 
-  if(arm2){
-    me <- list(posterior_treatment = posterior_treatment,
-               posterior_control   = posterior_control,
-               f1                  = f1,
-               args1               = args1)
-  } else{
-      me <- list(posterior_treatment = posterior_treatment,
-                 f1                  = f1,
-                 args1               = args1)
-  }
+  me <- list(posterior_treatment = posterior_treatment,
+             posterior_control   = posterior_control,
+             args1               = args1)
 
   class(me) <- "bdpbinomial"
 
@@ -407,22 +390,21 @@ posterior_binomial <- function(y, N, y0, N0, alpha_max, fix_alpha, a0, b0,
   if(!is.null(N) & !is.null(N0)){
 
     ### Test of model vs real
-    p_test <- mean(posterior_flat < prior)   # larger is higher failure
+    p_hat <- mean(posterior_flat < prior)   # larger is higher failure
 
     ### Number of effective sample size given shape and scale discount function
     if(fix_alpha == TRUE){
       alpha_discount <- alpha_max
     } else{
       if (!two_side) {
-        alpha_discount <- pweibull(p_test, shape=weibull_shape,
+        alpha_discount <- pweibull(p_hat, shape=weibull_shape,
                                    scale=weibull_scale)*alpha_max
       } else if (two_side){
-        p_test1    <- ifelse(p_test > 0.5, 1 - p_test, p_test)
-        alpha_discount <- pweibull(p_test1, shape=weibull_shape,
+        p_hat    <- ifelse(p_hat > 0.5, 1 - p_hat, p_hat)
+        alpha_discount <- pweibull(p_hat, shape=weibull_shape,
                                    scale=weibull_scale)*alpha_max
       }
     }
-    p_hat <- p_test
 
   } else{
     alpha_discount <- NULL
@@ -465,84 +447,3 @@ posterior_binomial <- function(y, N, y0, N0, alpha_max, fix_alpha, a0, b0,
 }
 
 
-
-
-################################################################################
-# Binomial: create final result class
-# - If no control, only returns posterior info for the treatment data
-# - TODO: Remove density() functions and have plot method compute
-#         densities on the fly
-################################################################################
-#' @title final_binomial
-#' @description final_binomial
-#' @param posterior_treatment posterior_treatment
-#' @param posterior_control posterior_control
-#' @rdname final_binomial
-#' @aliases final_binomial,ANY-method
-#' @export final_binomial
-setGeneric("final_binomial",
-           function(posterior_treatment = NULL,
-                    posterior_control   = NULL){
-    standardGeneric("final_binomial")
-  })
-
-  setMethod("final_binomial",
-            signature(),
-            function(posterior_treatment = NULL,
-                     posterior_control   = NULL){
-
-  density_post_treatment  <- density(posterior_treatment$posterior,
-                                     adjust = .5)
-
-  if(!is.null(posterior_treatment$posterior_flat)){
-    density_flat_treatment  <- density(posterior_treatment$posterior_flat,
-                                       adjust = .5)
-  } else{
-    density_flat_treatment <- NULL
-  }
-
-  if(!is.null(posterior_treatment$prior)){
-    density_prior_treatment <- density(posterior_treatment$prior,
-                                       adjust = .5)
-  } else{
-    density_prior_treatment <- NULL
-  }
-
-
-  if(is.null(posterior_control)){
-    treatment_posterior <- posterior_treatment$posterior
-
-    return(list(density_post_treatment  = density_post_treatment,
-                density_flat_treatment  = density_flat_treatment,
-                density_prior_treatment = density_prior_treatment,
-                treatment_posterior     = treatment_posterior))
-  } else{
-    density_post_control  <- density(posterior_control$posterior,
-                                     adjust = .5)
-
-    if(!is.null(posterior_control$posterior_flat)){
-      density_flat_control  <- density(posterior_control$posterior_flat,
-                                       adjust = .5)
-    } else{
-      density_flat_control <- NULL
-    }
-
-    if(!is.null(posterior_control$prior)){
-      density_prior_control <- density(posterior_control$prior,
-                                       adjust = .5)
-    } else{
-      density_prior_control <- NULL
-    }
-
-    comparison_posterior <- posterior_treatment$posterior - posterior_control$posterior
-
-    return(list(density_post_control    = density_post_control,
-                density_flat_control    = density_flat_control,
-                density_prior_control   = density_prior_control,
-                density_post_treatment  = density_post_treatment,
-                density_flat_treatment  = density_flat_treatment,
-                density_prior_treatment = density_prior_treatment,
-                comparison_posterior    = comparison_posterior))
-  }
-
-})
